@@ -2,7 +2,7 @@ import threading
 import time
 from collections import deque
 from datetime import datetime, timedelta, timezone
-from typing import Deque, List, Optional, Set, Tuple, Union
+from typing import Deque, List, Optional, Set, Union
 
 from cachetools import TTLCache
 from jose import JWTError, jwt
@@ -14,10 +14,9 @@ from starlette.responses import RedirectResponse
 
 from contaxy import config
 from contaxy.config import settings
-from contaxy.operations import AuthOperations, JsonDocumentOperations
+from contaxy.operations import AuthOperations, JsonDocumentOperations, ProjectOperations
 from contaxy.schema import AuthorizedAccess, TokenType, User, UserInput
 from contaxy.schema.auth import (
-    USERS_KIND,
     AccessLevel,
     AccessToken,
     ApiToken,
@@ -56,7 +55,6 @@ class ResourcePermissions(BaseModel):
 
 
 class AuthManager(AuthOperations):
-
     _USER_PASSWORD_COLLECTION = "passwords"
     _PERMISSION_COLLECTION = "permission"
     _API_TOKEN_COLLECTION = "tokens"
@@ -208,7 +206,8 @@ class AuthManager(AuthOperations):
         filtered_token_docs = self._json_db_manager.list_json_documents(
             config.SYSTEM_INTERNAL_PROJECT,
             self._API_TOKEN_COLLECTION,
-            filter=f'$.subject ==  "{token_subject}"',  # TODO: $.subject ==  "{token_subject}"  inmemory: $[? (@.subject ==  "{token_subject}")]'
+            filter=f'$.subject ==  "{token_subject}"',
+            # TODO: $.subject ==  "{token_subject}"  inmemory: $[? (@.subject ==  "{token_subject}")]'
         )
 
         api_tokens: List[ApiToken] = []
@@ -428,15 +427,6 @@ class AuthManager(AuthOperations):
         resource_name: str,
         permission: str,
     ) -> None:
-        """Grants a permission to the specified resource.
-
-        Args:
-            resource_name: The resource name that the permission is granted to.
-            permission: The permission to grant to the specified resource.
-
-        Raises:
-            ResourceUpdateFailedError: If the resource update could not be applied successfully.
-        """
         resource_permission = ResourcePermissions()
         try:
             # Try to get the permission document
@@ -475,6 +465,9 @@ class AuthManager(AuthOperations):
                 explanation="The resource did not exist anymore after the update.",
                 resource=resource_name,
             ) from ex
+        logger.debug(
+            f"Successfully added new permission {permission} to resource {resource_name}."
+        )
 
     def remove_permission(
         self, resource_name: str, permission: str, remove_sub_permissions: bool = False
@@ -636,7 +629,8 @@ class AuthManager(AuthOperations):
         filtered_resource_docs = self._json_db_manager.list_json_documents(
             config.SYSTEM_INTERNAL_PROJECT,
             self._PERMISSION_COLLECTION,
-            filter=f'$.permissions[*] ? (@=="{permission}")',  # TODO: - inmemory: $[*].permissions[?(@=="{permission}")]
+            filter=f'$.permissions[*] ? (@=="{permission}")',
+            # TODO: - inmemory: $[*].permissions[?(@=="{permission}")]
         )
 
         resource_names: Set[str] = set()
@@ -675,7 +669,7 @@ class AuthManager(AuthOperations):
 
         except ResourceNotFoundError as ex:
             # The user was not found in the system
-            raise OAuth2Error("invalid_request") from ex
+            raise OAuth2Error("unauthorized_client") from ex
 
     def _generate_token(
         self, user_id: str, scopes: Union[str, List[str], None] = None
@@ -748,8 +742,9 @@ class AuthManager(AuthOperations):
         self,
         code: str,
         redirect_uri: str,
+        project_manager: ProjectOperations,
         state: Optional[str] = None,
-    ) -> Tuple[OAuthToken, Optional[User]]:
+    ) -> OAuthToken:
         """Implements the OAuth2 / OICD callback to finish the login process.
 
         The authorization `code` is exchanged for an access and ID token.
@@ -761,6 +756,7 @@ class AuthManager(AuthOperations):
         Args:
             code: The authorization code generated by the authorization server.
             redirect_uri: The redirect uri used for the OICD authorization flow.
+            project_manager: Project manager required for creating new users
             state (optional): An opaque value used by the client to maintain state between the request and callback. The parameter SHOULD be used for preventing cross-site request forgery.
 
         Raises:
@@ -787,19 +783,22 @@ class AuthManager(AuthOperations):
         if not token_payload.get("email_verified"):
             # ? Prevent
             logger.warning(f"The email {email} is not verified")
-        user = None
         try:
             user_id = self._get_user_id_by_login_id(email)
         except ResourceNotFoundError:
             if config.settings.USER_REGISTRATION_ENABLED:
-                user = self.create_user(UserRegistration(email=email))
+                user = auth_utils.create_and_setup_user(
+                    user_input=UserRegistration(email=email),
+                    auth_manager=self,
+                    project_manager=project_manager,
+                )
                 user_id = user.id
             else:
                 raise PermissionDeniedError(
                     f"No existing account for {email} found! Please contact an administrator."
                 )
 
-        return self._generate_token(user_id), user
+        return self._generate_token(user_id)
 
     # User Operations
 
@@ -869,6 +868,7 @@ class AuthManager(AuthOperations):
         Returns:
             User: The created user information.
         """
+        logger.debug(f"User creation request for UserRegistration({user_input}).")
         user_id = id_utils.generate_short_uuid()
 
         if user_input.password:
@@ -920,20 +920,9 @@ class AuthManager(AuthOperations):
             key=user_id,
             json_document=user.json(),
         )
-
-        # TODO: get resource name from object
-        user_resource_name = USERS_KIND + "/" + user_id
-        self.add_permission(
-            user_resource_name,
-            auth_utils.construct_permission(user_resource_name, AccessLevel.ADMIN),
-        )
-        # User needs to know which images are allowed for deployments
-        self.add_permission(
-            user_resource_name,
-            auth_utils.construct_permission("system/allowed-images", AccessLevel.READ),
-        )
-
-        return User.parse_raw(created_document.json_value)
+        user = User.parse_raw(created_document.json_value)
+        logger.debug(f"Successfully created User({user}).")
+        return user
 
     def get_user(self, user_id: str) -> User:
         """Returns the user metadata for a single user.
