@@ -1,6 +1,7 @@
+import os
 import time
 from datetime import datetime, timezone
-from typing import List, Literal, Optional
+from typing import Any, List, Literal, Optional
 
 from kubernetes import client as kube_client
 from kubernetes import config as kube_config
@@ -36,7 +37,6 @@ from contaxy.managers.deployment.kube_utils import (
     wait_for_deployment,
     wait_for_job,
 )
-from contaxy.managers.deployment.manager import DeploymentManager
 from contaxy.managers.deployment.utils import (
     DEFAULT_DEPLOYMENT_ACTION_ID,
     NO_LOGS_MESSAGE,
@@ -45,8 +45,9 @@ from contaxy.managers.deployment.utils import (
     split_image_name_and_tag,
 )
 from contaxy.managers.system import SystemManager
+from contaxy.operations import DeploymentOperations
 from contaxy.schema import Job, JobInput, ResourceAction, Service, ServiceInput
-from contaxy.schema.deployment import DeploymentType
+from contaxy.schema.deployment import DeploymentType, ServiceUpdate
 from contaxy.schema.exceptions import (
     ClientBaseError,
     ClientValueError,
@@ -57,7 +58,7 @@ from contaxy.utils.auth_utils import parse_userid_from_resource_name
 from contaxy.utils.state_utils import GlobalState, RequestState
 
 
-class KubernetesDeploymentManager(DeploymentManager):
+class KubernetesDeploymentManager(DeploymentOperations):
     def __init__(
         self,
         global_state: GlobalState,
@@ -84,7 +85,7 @@ class KubernetesDeploymentManager(DeploymentManager):
             # incluster config is the config given by a service account and it's role permissions
             kube_config.load_incluster_config()
         except kube_config.ConfigException:
-            kube_config.load_kube_config()
+            kube_config.load_kube_config(context=os.getenv("CTXY_K8S_CONTEXT", None))
 
         self.core_api = kube_client.CoreV1Api()
         self.apps_api = kube_client.AppsV1Api()
@@ -238,6 +239,12 @@ class KubernetesDeploymentManager(DeploymentManager):
 
         return transformed_service
 
+    def update_service(
+        self, project_id: str, service_id: str, service: ServiceUpdate
+    ) -> Service:
+        # Service update is only implemented on DeploymentManagerWithDB wrapper
+        raise NotImplementedError()
+
     def list_deploy_service_actions(
         self, project_id: str, service: ServiceInput
     ) -> List[ResourceAction]:
@@ -602,3 +609,27 @@ class KubernetesDeploymentManager(DeploymentManager):
         return self.get_service_logs(
             project_id=project_id, service_id=job_id, lines=lines, since=since
         )
+
+    def suggest_service_config(
+        self, project_id: str, container_image: str
+    ) -> ServiceInput:
+        raise NotImplementedError()
+
+    def list_service_actions(
+        self, project_id: str, service_id: str
+    ) -> List[ResourceAction]:
+        raise NotImplementedError()
+
+    def execute_service_action(
+        self, project_id: str, service_id: str, action_id: str
+    ) -> Any:
+        raise NotImplementedError()
+
+    def suggest_job_config(self, project_id: str, container_image: str) -> JobInput:
+        raise NotImplementedError()
+
+    def list_job_actions(self, project_id: str, job_id: str) -> List[ResourceAction]:
+        raise NotImplementedError()
+
+    def execute_job_action(self, project_id: str, job_id: str, action_id: str) -> Any:
+        raise NotImplementedError()
